#include "utils.PRO2"


//e^x = suma_{i=0}^n x^i/i!
//e^x = x^0/0! + x^1/1! + x^2/2! + x^3/3! + ....

//Pre: n>=0
int fact(int n){
  int f = 1;
  while (n>0){
    f*=n;
    --n;
  }
  return f;
}
//Post: retorna n!


//Pre: a>0; b>=0
double pot ( double a, int b){
  double p=1;
  while (b>0) {
    p*=a;
    --b;
  }
  return p;
}
//Post: retorna a^b


//Pre: n>=0; 
double taylore(double x, int n){
  if (x==0) return 1;
  // x!=0
  double t=1;
  int i=1;
  //Inv: t = "suma fins i-1 de la sèrie de Taylor per a e^x"
  while (i<=n) {
    t+=pot(x,i)/fact(i);
    ++i;
  }
  return t;
}
//Post: retorna la suma fins a n de la serie de Taylor per a e^x


//Pre: n>=0
double etaylore(double x, int n){
  if (x==0) return 1;
  double t=1;
  int f=1;
  double p=1;
  int i=1;
  //Inv: t = "suma fins i-1 de la sèrie de Taylor per a e^x"
  //     p = x^(i-1) ; f=(i-1)!; 
  while (i<=n){
    p*=x; //p=x^i
    f*=i; //f=i!
    t+=p/f;
    ++i;
  }
  return t;
}
//Post: retorna la suma fins a n de la serie de Taylor per a e^x


//Pre: n>=0
double eetaylore(double x, int n){
  if (x==0) return 1;
  double t=1;
  double pf=1;
  int i=1;
  //Inv: t= "suma fins i-1 de la sèrie de Taylor per a e^x"
  //     pf = x^(i-1)/(i-1)!; 
  //     i<= n+1
  while (i<=n){
    pf*=x;  //pf = x^i/(i-1)!
    pf/=i; //pf=x^i/i!
    t+=pf;
    ++i;
  }
  //Postw: t = "suma fins a n de la serie de Taylor per a e^x"
  return t;
}
//Post: retorna la suma fins a n de la serie de Taylor per a e^x


/* 
Justificació:

Tractem el cas x=0 a part, per evitar càlculs que sempre donaran 0 i
evitar el cas 0^0. El bucle es fa en els demés casos.

1) Inicialitzacions: 

Com que "i" pren per valor 1, tenim que t=1 és la sèrie de taylor
fins i-1.  A més com que x!=0, tenim que pf=1 és x^0/0!.

2) Cos del bucle:

Per l'invariant pf=x^(i-1)/(i-1)! i, per tant, pf*x/i = x^i/i!
Igualment com "t" conté la suma fins a i-1, si ara li sumen "pf", que
conté x^i/i!, a "t", tenim la suma de la serie fins a "i". A
l'incrementar "i", tornem a tenir l'invariant.

3) Condició de sortida:

Quan i=n+1 tenim a "t" la suma fins a n de la serie de Taylor per a e^x

4) Acabament:

Decreix la distància entre la "n" i la "i". De fet perquè sempre sigui
positiva agafem com a mesura n-i+1.

 */

int main(){

  cout.setf(ios::fixed);
  cout.precision(14);

  int n;
  double x;
  cin >> x >> n; 
  cout << taylore(x, n) << endl;
  cout << etaylore(x, n) << endl;
  cout << eetaylore(x, n) << endl;

}

// 4 y 12
// 4 y 16
// 4 y 30

// 8 y 12
// 8 y ....
